#######
Methods
#######

Here is list of all available API methods:


Stickers
========

.. toctree::
    :maxdepth: 1

    add_sticker_to_set
    create_new_sticker_set
    delete_sticker_from_set
    delete_sticker_set
    get_custom_emoji_stickers
    get_sticker_set
    replace_sticker_in_set
    send_sticker
    set_custom_emoji_sticker_set_thumbnail
    set_sticker_emoji_list
    set_sticker_keywords
    set_sticker_mask_position
    set_sticker_position_in_set
    set_sticker_set_thumbnail
    set_sticker_set_title
    upload_sticker_file

Available methods
=================

.. toctree::
    :maxdepth: 1

    answer_callback_query
    approve_chat_join_request
    ban_chat_member
    ban_chat_sender_chat
    close
    close_forum_topic
    close_general_forum_topic
    convert_gift_to_stars
    copy_message
    copy_messages
    create_chat_invite_link
    create_chat_subscription_invite_link
    create_forum_topic
    decline_chat_join_request
    delete_business_messages
    delete_chat_photo
    delete_chat_sticker_set
    delete_forum_topic
    delete_my_commands
    delete_story
    edit_chat_invite_link
    edit_chat_subscription_invite_link
    edit_forum_topic
    edit_general_forum_topic
    edit_story
    export_chat_invite_link
    forward_message
    forward_messages
    get_available_gifts
    get_business_account_gifts
    get_business_account_star_balance
    get_business_connection
    get_chat
    get_chat_administrators
    get_chat_gifts
    get_chat_member
    get_chat_member_count
    get_chat_menu_button
    get_file
    get_forum_topic_icon_stickers
    get_me
    get_my_commands
    get_my_default_administrator_rights
    get_my_description
    get_my_name
    get_my_short_description
    get_user_chat_boosts
    get_user_gifts
    get_user_profile_photos
    gift_premium_subscription
    hide_general_forum_topic
    leave_chat
    log_out
    pin_chat_message
    post_story
    promote_chat_member
    read_business_message
    remove_business_account_profile_photo
    remove_chat_verification
    remove_user_verification
    reopen_forum_topic
    reopen_general_forum_topic
    repost_story
    restrict_chat_member
    revoke_chat_invite_link
    send_animation
    send_audio
    send_chat_action
    send_checklist
    send_contact
    send_dice
    send_document
    send_gift
    send_location
    send_media_group
    send_message
    send_message_draft
    send_paid_media
    send_photo
    send_poll
    send_venue
    send_video
    send_video_note
    send_voice
    set_business_account_bio
    set_business_account_gift_settings
    set_business_account_name
    set_business_account_profile_photo
    set_business_account_username
    set_chat_administrator_custom_title
    set_chat_description
    set_chat_menu_button
    set_chat_permissions
    set_chat_photo
    set_chat_sticker_set
    set_chat_title
    set_message_reaction
    set_my_commands
    set_my_default_administrator_rights
    set_my_description
    set_my_name
    set_my_short_description
    set_user_emoji_status
    transfer_business_account_stars
    transfer_gift
    unban_chat_member
    unban_chat_sender_chat
    unhide_general_forum_topic
    unpin_all_chat_messages
    unpin_all_forum_topic_messages
    unpin_all_general_forum_topic_messages
    unpin_chat_message
    upgrade_gift
    verify_chat
    verify_user

Updating messages
=================

.. toctree::
    :maxdepth: 1

    approve_suggested_post
    decline_suggested_post
    delete_message
    delete_messages
    edit_message_caption
    edit_message_checklist
    edit_message_live_location
    edit_message_media
    edit_message_reply_markup
    edit_message_text
    stop_message_live_location
    stop_poll

Inline mode
===========

.. toctree::
    :maxdepth: 1

    answer_inline_query
    answer_web_app_query
    save_prepared_inline_message

Games
=====

.. toctree::
    :maxdepth: 1

    get_game_high_scores
    send_game
    set_game_score

Payments
========

.. toctree::
    :maxdepth: 1

    answer_pre_checkout_query
    answer_shipping_query
    create_invoice_link
    edit_user_star_subscription
    get_my_star_balance
    get_star_transactions
    refund_star_payment
    send_invoice

Getting updates
===============

.. toctree::
    :maxdepth: 1

    delete_webhook
    get_updates
    get_webhook_info
    set_webhook

Telegram Passport
=================

.. toctree::
    :maxdepth: 1

    set_passport_data_errors
